@@ -1,8 +1,6 @@
 cd /workdir
-yum -y install centos-release-scl-rh
-yum -y install llvm-toolset-7.0 rh-nodejs12
-source scl_source enable llvm-toolset-7.0
-source scl_source enable rh-nodejs12
+dnf install -y dnf-plugins-core
+dnf module install -y nodejs:20 llvm-toolset:rhel8
 curl https://static.rust-lang.org/rustup/dist/$(uname -m)-unknown-linux-gnu/rustup-init --output rustup-init
 chmod +x rustup-init
 ./rustup-init -y --profile minimal
@@ -10,4 +8,4 @@ source "$HOME/.cargo/env"
 python3.12 -m venv venv
 source venv/bin/activate
 pip install maturin
-maturin build --release --compatibility manylinux2014
+maturin build --release --compatibility manylinux_2_28
