@@ -21,6 +21,7 @@ use std::fmt::Write;
 use tree_sitter::{Language, Node};
 
 pub struct FormatOptions {
+    /// Number of spaces used for one level of indentation
     pub indentation: usize,
 }
 
@@ -39,7 +40,7 @@ fn get_tree_sitter_turtle() -> Language {
 
 pub fn format_turtle(original: &str, options: &FormatOptions) -> Result<String> {
     let mut parser = tree_sitter::Parser::new();
-    parser.set_language(get_tree_sitter_turtle())?;
+    parser.set_language(&get_tree_sitter_turtle())?;
     let tree = parser.parse(original.as_bytes(), None).unwrap();
 
     let mut formatted = String::new();
@@ -60,7 +61,7 @@ struct TurtleFormatter<'a, W: Write> {
     prefixes: HashMap<String, String>,
 }
 
-impl<'a, W: Write> TurtleFormatter<'a, W> {
+impl<W: Write> TurtleFormatter<'_, W> {
     fn fmt_doc(&mut self, node: Node<'_>) -> Result<()> {
         debug_assert_eq!(node.kind(), "turtle_doc");
 
@@ -204,6 +205,14 @@ impl<'a, W: Write> TurtleFormatter<'a, W> {
         self.fmt_comments(comments, true)
     }
 
+    fn new_indented_line(&mut self, indents: usize) -> Result<()> {
+        writeln!(self.output)?;
+        for _ in 0..(self.options.indentation * indents) {
+            write!(self.output, " ")?;
+        }
+        Ok(())
+    }
+
     fn fmt_triples(&mut self, node: Node<'_>) -> Result<()> {
         debug_assert_eq!(node.kind(), "triples");
         let mut comments = Vec::new();
@@ -218,10 +227,7 @@ impl<'a, W: Write> TurtleFormatter<'a, W> {
                     } else {
                         write!(self.output, " ;")?;
                         self.fmt_comments(comments.drain(0..), true)?;
-                        writeln!(self.output)?;
-                        for _ in 0..self.options.indentation {
-                            write!(self.output, " ")?;
-                        }
+                        self.new_indented_line(1)?;
                     }
                     self.fmt_predicate_objects(child, &mut comments)?;
                 }
@@ -625,7 +631,7 @@ impl<'a> StringDecoder<'a> {
     }
 }
 
-impl<'a> Iterator for StringDecoder<'a> {
+impl Iterator for StringDecoder<'_> {
     type Item = Result<char>;
 
     fn next(&mut self) -> Option<Result<char>> {
@@ -687,7 +693,7 @@ fn is_turtle_decimal(value: &str) -> bool {
     if value.starts_with(b"+") || value.starts_with(b"-") {
         value = &value[1..];
     }
-    while value.first().map_or(false, |c| c.is_ascii_digit()) {
+    while value.first().is_some_and(|c| c.is_ascii_digit()) {
         value = &value[1..];
     }
     if !value.starts_with(b".") {
@@ -705,14 +711,14 @@ fn is_turtle_double(value: &str) -> bool {
         value = &value[1..];
     }
     let mut with_before = false;
-    while value.first().map_or(false, |c| c.is_ascii_digit()) {
+    while value.first().is_some_and(|c| c.is_ascii_digit()) {
         value = &value[1..];
         with_before = true;
     }
     let mut with_after = false;
     if value.starts_with(b".") {
         value = &value[1..];
-        while value.first().map_or(false, |c| c.is_ascii_digit()) {
+        while value.first().is_some_and(|c| c.is_ascii_digit()) {
             value = &value[1..];
             with_after = true;
         }
@@ -734,21 +740,3 @@ enum RootContext {
     Triples,
     Comment,
 }
-
-#[cfg(test)]
-mod tests {
-    use super::*;
-    use std::path::Path;
-
-    #[test]
-    fn tree_sitter() -> Result<()> {
-        tree_sitter_cli::test::run_tests_at_path(
-            get_tree_sitter_turtle(),
-            &Path::new("tree-sitter").join("corpus"),
-            false,
-            false,
-            None,
-            false,
-        )
-    }
-}
